CborInteger

Struct CborInteger 

pub struct CborInteger(/* private fields */);
Available on crate feature alloc only.
An integer value permitted by SACP-CBOR/1.

Implementations

Source

impl CborInteger

pub fn safe(value: i64) -> Result<Self, CborError>

Construct a safe-range integer.

Errors

Returns IntegerOutsideSafeRange if the value is outside the safe range.

pub fn big(negative: bool, magnitude: Vec<u8>) -> Result<Self, CborError>

Construct a bignum integer from sign and magnitude bytes.

Errors

Returns an error if the magnitude is not canonical or is within the safe integer range.

pub const fn from_bigint(big: BigInt) -> Self

Construct a bignum integer from an existing BigInt.

pub const fn is_safe(&self) -> bool

Returns true iff this is a safe-range integer.

pub const fn is_big(&self) -> bool

Returns true iff this is a bignum integer.

pub const fn as_i64(&self) -> Option<i64>

Return the safe integer value if available.

pub const fn as_bigint(&self) -> Option<&BigInt>

Return the underlying bignum if available.