pub struct Decoder<'de, const CHECKED: bool> { /* private fields */ }Expand description
Streaming decoder over canonical CBOR bytes.
Implementations
Sourceimpl<'de> Decoder<'de, true>
impl<'de> Decoder<'de, true>
Sourcepub const fn new_checked(
bytes: &'de [u8],
limits: DecodeLimits,
) -> Result<Self, CborError>
pub const fn new_checked( bytes: &'de [u8], limits: DecodeLimits, ) -> Result<Self, CborError>
Construct a decoder that enforces canonical constraints while decoding.
Errors
Returns MessageLenLimitExceeded if bytes exceeds the input limit.
Sourceimpl<'de> Decoder<'de, false>
impl<'de> Decoder<'de, false>
Sourcepub const fn new_trusted(
canon: CanonicalCborRef<'de>,
limits: DecodeLimits,
) -> Result<Self, CborError>
pub const fn new_trusted( canon: CanonicalCborRef<'de>, limits: DecodeLimits, ) -> Result<Self, CborError>
Construct a decoder over canonical bytes with the provided limits.
This assumes the input is already canonical.
Errors
Returns MessageLenLimitExceeded if bytes exceeds the input limit.
Sourceimpl<'de, const CHECKED: bool> Decoder<'de, CHECKED>
impl<'de, const CHECKED: bool> Decoder<'de, CHECKED>
Sourcepub fn array(&mut self) -> Result<ArrayDecoder<'_, 'de, CHECKED>, CborError>
pub fn array(&mut self) -> Result<ArrayDecoder<'_, 'de, CHECKED>, CborError>
Decode an array header and return a guard for its elements.
Errors
Returns ExpectedArray if the next value is not an array, or a limit error.
Sourcepub fn map(&mut self) -> Result<MapDecoder<'_, 'de, CHECKED>, CborError>
pub fn map(&mut self) -> Result<MapDecoder<'_, 'de, CHECKED>, CborError>
Decode a map header and return a guard for its entries.
Errors
Returns ExpectedMap if the next value is not a map, or a limit error.