pub struct CborInteger(/* private fields */);Available on crate feature
alloc only.Expand description
An integer value permitted by SACP-CBOR/1.
Implementations
Sourceimpl CborInteger
impl CborInteger
Sourcepub fn safe(value: i64) -> Result<Self, CborError>
pub fn safe(value: i64) -> Result<Self, CborError>
Construct a safe-range integer.
Errors
Returns IntegerOutsideSafeRange if the value is outside the safe range.
Sourcepub fn big(negative: bool, magnitude: Vec<u8>) -> Result<Self, CborError>
pub fn big(negative: bool, magnitude: Vec<u8>) -> Result<Self, CborError>
Construct a bignum integer from sign and magnitude bytes.
Errors
Returns an error if the magnitude is not canonical or is within the safe integer range.
Sourcepub const fn from_bigint(big: BigInt) -> Self
pub const fn from_bigint(big: BigInt) -> Self
Construct a bignum integer from an existing BigInt.